####################################################################
#Global threat status, rarity and species distribution affect      #
#prevalence of Atlantic Forest endemic birds in citizen collected  #
# datasets                                                         #
####################################################################

# Date:07/jun/2024

# Lucas Rodriguez Forti

## Models atlantic birds

## libraries
library(dplyr)
library(tidyverse)
library(lme4)
library(lmerTest)
library(performance)

#calling data

setwd("path")

dados <- read.csv2("dados.csv", header=TRUE, fileEncoding="latin1")
dados
glimpse(dados)
dados$eoo

dados <- dados %>% filter(n > 2) #removing mitu mitu


#transformations
dados$range <- as.numeric(dados$range)
dados$median <- as.numeric(dados$median)
dados$eoo <- as.numeric(dados$eoo)
dados$max <- as.numeric(dados$max)
dados$mass <- as.numeric(dados$mass)
dados$biomass <- as.numeric(dados$biomass)

glimpse(dados)

View(dados)

## colinearity checking

plot(log10(dados$median), log10(dados$eoo))

hist(log10(dados$median))
hist(log10(dados$eoo))
shapiro.test(log10(dados$median))

cor.test(log10(dados$median), log10(dados$range),  method = "spearman",
         use = "complete.obs")

cor.test(log10(dados$eoo), log10(dados$range),  method = "spearman",
         use = "complete.obs")

cor.test(log10(dados$eoo), log10(dados$median),  method = "spearman",
         use = "complete.obs")
#####

# MODELS

mod1 <- lmer(log10(n) ~ log10(range) +(1|family) + (1|iucn),
                na.action = na.exclude, data = dados)

summary(mod1)
qqnorm(resid(mod1))
qqline(resid(mod1))  # points fall nicely onto the line?
confint.merMod(mod1)
model_performance(mod1)
check_singularity(mod1)

# Alternative model with biomass

mod2 <- lmer(log10(n) ~ log10(biomass) +(1|family) + (1|iucn),
             na.action = na.exclude, data = dados)

summary(mod2)
qqnorm(resid(mod2))
qqline(resid(mod2))  # points fall nicely onto the line?
confint.merMod(mod2)
model_performance(mod2)
check_singularity(mod2)

##second alternative (Here the result is a singular fit)

mod3 <- lmer(log10(n) ~log10(range) + log10(biomass) +(1|family) + (1|iucn),
             na.action = na.exclude, data = dados)


## comparing models
compare_performance(mod1, mod2, verbose = FALSE)


## an extra model to test the slopes among iucn status
mod4 <- lm(log10(n) ~ log10(range)*iucn,
           na.action = na.exclude, data = dados)
summary(mod4)
qqnorm(resid(mod4))
qqline(resid(mod4))  # points fall nicely onto the line?
confint.merMod(mod4)
model_performance(mod4)
check_singularity(mod4)

## checking for correlations random factors

mod5<- lm(log10(range) ~ iucn,
          na.action = na.exclude, data = dados)

summary(mod5)
qqnorm(resid(mod5))
qqline(resid(mod5))  # points fall nicely onto the line?
confint.merMod(mod5)
check_collinearity(mod5)
model_performance(mod5)
check_singularity(mod5)

mod6 <- lm(log10(range) ~ family,
           na.action = na.exclude, data = dados)

summary(mod6)
qqnorm(resid(mod6))
qqline(resid(mod6))  # points fall nicely onto the line?
confint.merMod(mod6)
check_collinearity(mod6)
model_performance(mod6)
check_singularity(mod6)


## biomass

mod51<- lm(log10(biomass) ~ iucn,
           na.action = na.exclude, data = dados)

summary(mod51)
qqnorm(resid(mod51))
qqline(resid(mod51))  # points fall nicely onto the line?
confint.merMod(mod51)
check_collinearity(mod15)
model_performance(mod51)
check_singularity(mod51)

mod61 <- lm(log10(biomass) ~ family,
            na.action = na.exclude, data = dados)

summary(mod61)
qqnorm(resid(mod61))
qqline(resid(mod61))  # points fall nicely onto the line?
confint.merMod(mod61)
check_collinearity(mod61)
model_performance(mod61)
check_singularity(mod61)

## model 7 to explore biomass with random intercept (1|iucn)

names(dados)

model7 <- lmer(log10(n) ~ log10(biomass) + (1|iucn),
               na.action = na.exclude, data = dados)
summary(model7)
qqnorm(resid(model7))
qqline(resid(model7))  # points fall nicely onto the line?
confint.merMod(model7)
check_collinearity(model7)
model_performance(model7)
check_singularity(model7)

## model 8 - random intercept model (range|iucn). 

model8 <- lmer(log10(n) ~ log10(biomass) + (range|iucn),
               na.action = na.exclude, data = dados)
summary(model8)
qqnorm(resid(model8))
qqline(resid(model8))  # points fall nicely onto the line?
confint.merMod(model8)
check_collinearity(model8)
model_performance(model8)
check_singularity(model8)